


/****************************************************************************
;
; NAME: ostransport.h
;
;
; DESCRIPTION:
;
;       Linux transport header
;
;
; REVISION HISTORY:
;
;       $Log: /ClrtyFC8/vmware40/vib/ostransport.h $
; 
; 4     2/14/11 2:38p Pcullen
; Add support for NPIV in Celerity8 driver.
; 
; 3     4/22/10 8:55a Pcullen
; Comply with transport interface changes made for esas
; 
; 2     10/30/09 9:19a Pcullen
; VMware 4 porting
; Removed the ESX 3.5 definitions of transport functions.
; 
; 1     8/06/09 1:33p Pcullen
; Provide more complete implementation of Linux FC Transport, including
; remote port api (rports)
; 
;
;
; THIS PROGRAM AND THE INFORMATION CONTAINED HEREIN IS THE PROPERTY OF
; ATTO TECHNOLOGY, INC. AND SHALL NOT BE REPRODUCED, COPIED, OR USED IN
; WHOLE OR IN PART OTHER THAN AS PROVIDED FOR IN THE LICENSE AGREEMENT
; PURSUANT TO WHICH IT WAS FURNISHED.
;
; COPYRIGHT (c) ATTO TECHNOLOGY, INC. 2009
; ALL RIGHTS RESERVED.
;
;***************************************************************************/

#ifndef _OSTRANSPORT_H_
#define _OSTRANSPORT_H_

#ifndef ATTO_USE_TRANSPORT
#error Including ostransport.h and ATTO_USE_TRANSPORT not defined
#endif

#ifndef CELERITYFC
#error Including ostransport.h and CELERITYFC not defined
#endif

#include <scsi/scsi_host.h>
#include <scsi/scsi_transport_fc.h>

/* Transport functions for Fibre Channel (see ostransport.c) */

#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,9)

#define ATTO_TRANSPORT
struct scsi_transport_template *atto_get_transport_template (void);
int atto_attach_transport (void);
void atto_release_transport (void);
void atto_init_host_attr (struct Scsi_Host *sh, int index);

#if defined (ATTO_USE_RPORTS) && LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,17)
#define ATTO_RPORTS
void celerityfc_add_rport (struct Scsi_Host *host, unsigned int target_id);
void celerityfc_remove_rport (struct Scsi_Host *host, unsigned int target_id);
void celerityfc_scan_rport (struct Scsi_Host *host, unsigned int target_id);
#endif

#else /* LINUX_VERSION_CORE < KERNEL_VERSION(2,6,9) */

#define atto_get_transport_template() NULL
#define atto_attach_transport()       1
#define atto_release_transport()
#define atto_init_host_attr(_sh, _index)

#endif /* LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,9) */

#ifdef ATTO_USE_NPIV

#define VPORT_DISC_POLL_TIME 500 /* msecs */

#define VPORT_INIT_POLL_TIME 200 /* msecs */

#ifndef CELERITY8FC
#error ATTO_USE_NPIV is defined and CELERITY8FC is not!
#endif

/* The following are declared in oswrap.c for physical host creation. */
/* They are needed here when creating virtual ports.                  */
extern int can_queue;
extern int cmd_per_lun;
extern int sg_tablesize;
extern int atto_max_sectors;
extern int max_logins;
extern int max_npiv_vports;
extern int max_npiv_logins;
extern int npiv_disc_wait_time;
extern int npiv_init_retries;

extern Scsi_Host_Template atto_vport_template;
void ShwFromScsiHost (PSHW shw, struct Scsi_Host *host);
extern void LinuxScheduleWork (unsigned int index);

/* The vport entry points from the FC transport API. */
int celerityfc_vport_create  (struct fc_vport *, bool);
int celerityfc_vport_disable (struct fc_vport *, bool);
int celerityfc_vport_delete  (struct fc_vport *);
#endif /* ATTO_USE_NPIV */

#endif /* _OSTRANSPORT_H_ */
